@@ -27,8 +27,11 @@ from .nbdimeserver import (
 from ..gitfiles import (
     changed_notebooks, is_path_in_repo, find_repo_root,
     InvalidGitRepositoryError, BadName, GitCommandNotFound,
+    apply_possible_filter
     )
 from ..utils import split_os_path, EXPLICIT_MISSING_FILE, read_notebook
+from ..config import build_config
+from ..diffing.notebooks import set_notebook_diff_ignores
 
 
 class AuthMainDifftoolHandler(MainDifftoolHandler):
@@ -207,6 +210,11 @@ def _load_jupyter_server_extension(nb_server_app):
         FileSystemLoader(template_path),
     ])
 
+    config = build_config('extension')
+    ignore = config.pop('Ignore', None)
+    if ignore:
+        set_notebook_diff_ignores(ignore)
+
     web_app.settings['static_path'].append(static_path)
 
     params = {
